@@ -1,7 +1,7 @@
 """
 Contains some common filter as utilities
 """
-from django.template import Library
+from django.template import Library, loader, Context
 from django.contrib.admin.templatetags.admin_list import result_headers, result_hidden_fields, results, admin_actions
 
 
@@ -9,18 +9,17 @@ register = Library()
 
 admin_actions = admin_actions
 
-@register.inclusion_tag("totalsum_change_list_results.html")
-def totalsum_result_list(cl, totals, unit_of_measure):
-    """
-    Displays the headers and data list together
-    """
+
+@register.simple_tag(takes_context=True)
+def totalsum_result_list(context, cl, totals, unit_of_measure, template_name="totalsum_change_list_results.html"):
+
     pagination_required = (not cl.show_all or not cl.can_show_all) and cl.multi_page
     headers = list(result_headers(cl))
     num_sorted_fields = 0
     for h in headers:
         if h['sortable'] and h['sorted']:
             num_sorted_fields += 1
-    return {
+    c = {
         'cl': cl,
         'totals': totals,
         'unit_of_measure': unit_of_measure,
@@ -31,9 +30,12 @@ def totalsum_result_list(cl, totals, unit_of_measure):
         'pagination_required': pagination_required
     }
 
+    t = loader.get_template(template_name)
+    return t.render(Context(c))
+
 
 @register.filter
 def get_total(totals, column):
-    if column.lower() in totals.keys():
-        return totals[column.lower()]
+    if column in totals.keys():
+        return totals[column]
     return ''
\ No newline at end of file
